Learn R Programming

DTEAssurance (version 1.1.0)

assurance_adaptive_shiny_app: Launch the 'shiny' adaptive assurance app

Description

Launches a 'shiny' application to simulate group sequential trials with delayed treatment effects (DTE) using elicited prior distributions. The app allows interactive exploration of trial designs and assurance calculations.

Usage

assurance_adaptive_shiny_app()

Arguments

Value

No return value, called for side effects (invisibly returns NULL). The function launches an interactive 'shiny' application.

Examples

Run this code
if (FALSE) {
# Launch the interactive Shiny app
assurance_adaptive_shiny_app()
}

Run the code above in your browser using DataLab